Vector of 6033 z-values comparing gene expression between prostate cancer patients and controls, as pictured in Figure 3.4. These were computed as described on page 272.
Format
A data frame with 6033 rows and 1 variable:
- z
Z-value for each gene comparing cancer vs control expression